# text to audio file converter by python
I make a Python based text to audio file converter project. this project  is a open source project. You can download  this project.

To run this project , first run :-

        pip install textaudio

Now, for use this package, you need some packages.

to use thease package, install this packages first :-

        pip install gtts

        pip install playsound

        pip install pyautogui

after run those commands, run command :-

make a file in anyware in desktop. ex; 'xyz.py'.

after making thease file, insert this line to the file :-

        from textaudio import main

then, call the main function via :- 

        main()

then a GUI has open.

 now follow the GUI instructions and convert a text massage into a audio file & save in your desktop.
